﻿using DotNetCore.CAP;
using Hotline.DataSharing;
using Hotline.DataSharing.Enterprise;
using Hotline.Share.Dtos.DataSharing;
using Hotline.Share.Dtos.DataSharing.Enterprise.Receive;
using MapsterMapper;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Sharing.Share.Dtos.DataSharing.Enterprise;
using XF.Domain.Filters;
using XF.Domain.Repository;

namespace Hotline.Api.Controllers.DataSharing
{
    /// <summary>
    /// 企业专班
    /// </summary>
    public class EnterpriseController : BaseController
    {
        private readonly IMapper _mapper;
        private readonly IRepository<DsReceiveWriteResult> _receiveWriteResultRepository;
        private readonly EnterpriseClient _enterpriseClient;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="mapper"></param>
        /// <param name="receiveWriteResultRepository"></param>
        public EnterpriseController(IMapper mapper, IRepository<DsReceiveWriteResult> receiveWriteResultRepository, EnterpriseClient enterpriseClient)
        {
            _mapper = mapper;
            _receiveWriteResultRepository = receiveWriteResultRepository;
            _enterpriseClient = enterpriseClient;
        }

        /// <summary>
        /// 查询企业专班
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost("platform/12345/selectEnterpriseList")]
        [AllowAnonymous]
        public async Task<OpenResponse> GetEnterpriseList(SelectEnterpriseListDto dto)
        {
            var request = new SelectEnterpriseListRequest();

            var enterpriseList = _mapper.Map<SelectEnterpriseList>(dto);
            request.SetData(enterpriseList);

            var response = await _enterpriseClient.RequestAsync<SelectEnterpriseListRequest, EnterpriseResponse>(request, HttpContext.RequestAborted);// await _enterprisePusher.SelectEnterpriseListAsync(request, HttpContext.RequestAborted);

            if (response != null)
            {
                if (response.success == true && response.data != null)
                {
                    return OpenResponse.Ok(System.Text.Json.JsonSerializer.Deserialize<EnRecordsDto>(response.data.ToString()));
                }
            }
            return OpenResponse.Ok("");
        }

        /// <summary>
        /// 企业服务提交办理结果
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost("api/yb12345/enterprise/writeResult")]
        [AllowAnonymous]
        public async Task<OpenResponse> WriteResult(WriteResultDto dto)
        {
            //验证数据
            string strResult = dto.Validate();
            if (!string.IsNullOrEmpty(strResult))
                return OpenResponse.Ok(EnterpriseDeResponse.Failed(description: strResult));

            var data = _mapper.Map<DsReceiveWriteResult>(dto);

            var id = await _receiveWriteResultRepository.AddAsync(data, HttpContext.RequestAborted);
            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                // await _capPublisher.PublishAsync("", _mapper.Map<DataWriteResultDto>(dto), cancellationToken: HttpContext.RequestAborted);
                //这里往业务系统推送数据
                return OpenResponse.Ok(EnterpriseDeResponse.Success("回复提交成功"));
            }
            return OpenResponse.Ok(EnterpriseDeResponse.Failed("接口调用失败！"));
        }
    }
}
